==> gnus-5.4.10.tar.gz: gnus-5.4.10/lisp/gnus-load.el <==
;;; gnus-load.el --- automatically extracted custom dependencies
;;
;;; Code:

(put 'gnus-visual 'custom-loads '("smiley" "gnus-sum" "gnus-picon" "earcon"))
(put 'gnus-summary-maneuvering 'custom-loads '("gnus-sum"))
(put 'gnus-start 'custom-loads '("gnus" "gnus-util" "gnus-start" "gnus-int"))
(put 'gnus-extract-view 'custom-loads '("gnus-sum"))
(put 'article-hiding-headers 'custom-loads '("gnus-sum"))
(put 'gnus-various 'custom-loads '("gnus-sum"))
(put 'gnus-meta 'custom-loads '("gnus"))
(put 'message-news 'custom-loads '("message"))
(put 'gnus-thread 'custom-loads '("gnus-sum"))
(put 'gnus-treading 'custom-loads '("gnus-sum"))
(put 'message-various 'custom-loads '("message"))
(put 'gnus-summary-exit 'custom-loads '("gnus-sum"))
(put 'gnus 'custom-loads '("nnmail" "gnus" "gnus-win" "gnus-uu" "gnus-sum" "gnus-group" "gnus-eform" "gnus-dup" "gnus-demon" "gnus-cache" "gnus-async" "gnus-art"))
(put 'gnus-summary-visual 'custom-loads '("gnus-sum"))
(put 'gnus-score 'custom-loads '("gnus-sum" "gnus-score" "gnus-nocem" "gnus-kill"))
(put 'gnus-group-select 'custom-loads '("gnus-sum"))
(put 'message-buffers 'custom-loads '("message"))
(put 'gnus-threading 'custom-loads '("gnus-sum"))
(put 'article 'custom-loads '("gnus-sum" "gnus-cite" "gnus-art"))
(put 'gnus-nocem 'custom-loads '("gnus-nocem"))
(put 'gnus-cite 'custom-loads '("gnus-cite"))
(put 'gnus-demon 'custom-loads '("gnus-demon"))
(put 'gnus-mail 'custom-loads '("nnmail"))
(put 'message-interface 'custom-loads '("message"))
(put 'gnus-edit-form 'custom-loads '("gnus-eform"))
(put 'emacs 'custom-loads '("custom" "widget-edit" "message" "gnus" "custom-opt"))
(put 'gnus-summary-mail 'custom-loads '("gnus-sum"))
(put 'gnus-topic 'custom-loads '("gnus-topic"))
(put 'gnus-summary-choose 'custom-loads '("gnus-sum"))
(put 'message-headers 'custom-loads '("message"))
(put 'message-forwarding 'custom-loads '("message"))
(put 'gnus-duplicate 'custom-loads '("gnus-dup"))
(put 'widgets 'custom-loads '("widget-edit"))
(put 'earcon 'custom-loads '("earcon"))
(put 'gnus-summary-format 'custom-loads '("gnus-sum"))
(put 'gnus-windows 'custom-loads '("gnus-win"))
(put 'gnus-summary 'custom-loads '("gnus-sum"))
(put 'gnus-group 'custom-loads '("gnus-topic" "gnus-sum" "gnus-group"))
(put 'gnus-summary-marks 'custom-loads '("gnus-sum"))
(put 'message-mail 'custom-loads '("message"))
(put 'gnus-summary-various 'custom-loads '("gnus-sum"))
(put 'message 'custom-loads '("message"))
(put 'message-sending 'custom-loads '("message"))
(put 'message-insertion 'custom-loads '("message"))
(put 'gnus-summary-sort 'custom-loads '("gnus-sum"))
(put 'customize 'custom-loads '("custom" "custom-edit"))
(put 'gnus-asynchronous 'custom-loads '("gnus-async"))
(put 'article-mime 'custom-loads '("gnus-sum"))
(put 'gnus-extract 'custom-loads '("gnus-uu" "gnus-sum"))
(put 'article-various 'custom-loads '("gnus-sum"))
(put 'mesage-sending 'custom-loads '("message"))
(put 'picons 'custom-loads '("gnus-picon"))

(provide 'gnus-load)

;;; gnus-load.el ends here

==> gnus-5.4.20.tar.gz: gnus-5.4.20/lisp/gnus-load.el <==
;;; gnus-load.el --- automatically extracted custom dependencies
;;
;;; Code:

(put 'gnus-visual 'custom-loads '("smiley" "gnus-sum" "gnus-picon" "earcon"))
(put 'gnus-summary-maneuvering 'custom-loads '("gnus-sum"))
(put 'gnus-start 'custom-loads '("gnus" "gnus-util" "gnus-start" "gnus-int"))
(put 'gnus-extract-view 'custom-loads '("gnus-sum"))
(put 'article-hiding-headers 'custom-loads '("gnus-sum"))
(put 'gnus-various 'custom-loads '("gnus-sum"))
(put 'gnus-meta 'custom-loads '("gnus"))
(put 'message-news 'custom-loads '("message"))
(put 'gnus-thread 'custom-loads '("gnus-sum"))
(put 'gnus-treading 'custom-loads '("gnus-sum"))
(put 'message-various 'custom-loads '("message"))
(put 'gnus-summary-exit 'custom-loads '("gnus-sum"))
(put 'gnus 'custom-loads '("nnmail" "gnus" "gnus-win" "gnus-uu" "gnus-sum" "gnus-group" "gnus-eform" "gnus-dup" "gnus-demon" "gnus-cache" "gnus-async" "gnus-art"))
(put 'gnus-summary-visual 'custom-loads '("gnus-sum"))
(put 'gnus-score 'custom-loads '("gnus-sum" "gnus-score" "gnus-nocem" "gnus-kill"))
(put 'gnus-group-select 'custom-loads '("gnus-sum"))
(put 'message-buffers 'custom-loads '("message"))
(put 'gnus-threading 'custom-loads '("gnus-sum"))
(put 'article 'custom-loads '("gnus-sum" "gnus-cite" "gnus-art"))
(put 'gnus-nocem 'custom-loads '("gnus-nocem"))
(put 'gnus-cite 'custom-loads '("gnus-cite"))
(put 'gnus-demon 'custom-loads '("gnus-demon"))
(put 'gnus-mail 'custom-loads '("nnmail"))
(put 'message-interface 'custom-loads '("message"))
(put 'gnus-edit-form 'custom-loads '("gnus-eform"))
(put 'emacs 'custom-loads '("custom" "widget-edit" "message" "gnus" "custom-opt"))
(put 'gnus-summary-mail 'custom-loads '("gnus-sum"))
(put 'gnus-topic 'custom-loads '("gnus-topic"))
(put 'gnus-summary-choose 'custom-loads '("gnus-sum"))
(put 'message-headers 'custom-loads '("message"))
(put 'message-forwarding 'custom-loads '("message"))
(put 'gnus-duplicate 'custom-loads '("gnus-dup"))
(put 'widgets 'custom-loads '("widget-edit"))
(put 'earcon 'custom-loads '("earcon"))
(put 'gnus-summary-format 'custom-loads '("gnus-sum"))
(put 'gnus-windows 'custom-loads '("gnus-win"))
(put 'gnus-summary 'custom-loads '("gnus-sum"))
(put 'gnus-group 'custom-loads '("gnus-topic" "gnus-sum" "gnus-group"))
(put 'gnus-summary-marks 'custom-loads '("gnus-sum"))
(put 'message-mail 'custom-loads '("message"))
(put 'gnus-summary-various 'custom-loads '("gnus-sum"))
(put 'message 'custom-loads '("message"))
(put 'message-sending 'custom-loads '("message"))
(put 'message-insertion 'custom-loads '("message"))
(put 'gnus-summary-sort 'custom-loads '("gnus-sum"))
(put 'customize 'custom-loads '("custom" "cus-edit"))
(put 'gnus-asynchronous 'custom-loads '("gnus-async"))
(put 'article-mime 'custom-loads '("gnus-sum"))
(put 'gnus-extract 'custom-loads '("gnus-uu" "gnus-sum"))
(put 'article-various 'custom-loads '("gnus-sum"))
(put 'mesage-sending 'custom-loads '("message"))
(put 'picons 'custom-loads '("gnus-picon"))

(provide 'gnus-load)

;;; gnus-load.el ends here
